|image0| |image1| |image2| |image3|

youtube2mp3
===========
a wrapper to simplify youtube downloads with `youtube-dl <https://github.com/rg3/youtube-dl>`_

downloaded files will be tagged with `mutagen <https://pypi.python.org/pypi/mutagen>`_

installation
------------
with pip
""""""""
::

    pip install youtube2mp3


usage
-----
::

    youtube2mp3 [options] arg1 arg2

see *youtube2mp3 -h* for more information

development
-----------
Create a virtual environment
::

    python3 -m venv /path/to/new/virtual/environment

install dependencies
::

    pip install -r requirements.txt


.. |image0| image:: https://img.shields.io/pypi/v/youtube2mp3.svg
     :target: https://pypi.python.org/pypi?name=youtube2mp3&:action=display
     :alt: pypi

.. |image1| image:: https://pyup.io/repos/github/pfitzer/youtube2mp3/shield.svg
     :target: https://pyup.io/repos/github/pfitzer/youtube2mp3/
     :alt: Updates

.. |image2| image:: https://pyup.io/repos/github/pfitzer/youtube2mp3/python-3-shield.svg
     :target: https://pyup.io/repos/github/pfitzer/youtube2mp3/
     :alt: Python ::
     
.. |image3| image:: https://img.shields.io/pypi/dm/youtube2mp3.svg
    :target: https://pyup.io/repos/github/pfitzer/youtube2mp3/
    :alt: PyPI - Downloads
